@@ -9,10 +9,11 @@ module Twitter
     extend Forwardable
     include Memoizable
     include Twitter::Utils
+    # @return [Hash]
     attr_reader :attrs
-    alias_method :to_h, :attrs
-    deprecate_alias :to_hash, :to_h
-    deprecate_alias :to_hsh, :to_h
+    alias to_h attrs
+    alias to_hash to_h
+    deprecate_alias :to_hsh, :to_hash
 
     class << self
       # Define methods that retrieve the value from attributes
@@ -72,7 +73,7 @@ module Twitter
       # @param key2 [Symbol]
       def define_uri_method(key1, key2)
         define_method(key1) do ||
-          Addressable::URI.parse(@attrs[key2]) unless @attrs[key2].nil?
+          Addressable::URI.parse(@attrs[key2].chomp('#')) unless @attrs[key2].nil?
         end
         memoize(key1)
       end
@@ -84,22 +85,18 @@ module Twitter
       # @param key2 [Symbol]
       def define_attribute_method(key1, klass = nil, key2 = nil)
         define_method(key1) do ||
-          if @attrs[key1].nil? || @attrs[key1].respond_to?(:empty?) && @attrs[key1].empty?
+          if attr_falsey_or_empty?(key1)
             NullObject.new
+          elsif klass.nil?
+            @attrs[key1]
           else
-            if klass.nil?
-              @attrs[key1]
-            else
-              attrs = attrs_for_object(key1, key2)
-              Twitter.const_get(klass).new(attrs)
-            end
+            attrs = attrs_for_object(key1, key2)
+            Twitter.const_get(klass).new(attrs)
           end
         end
         memoize(key1)
       end
 
-      # Dynamically define a method for an attribute
-      #
       # @param key [Symbol]
       def deprecate_attribute_method(key)
         define_method(key) do ||
@@ -115,7 +112,7 @@ module Twitter
       # @param key2 [Symbol]
       def define_predicate_method(key1, key2 = key1)
         define_method(:"#{key1}?") do ||
-          !@attrs[key2].nil? && @attrs[key2] != false && !(@attrs[key2].respond_to?(:empty?) && @attrs[key2].empty?)
+          !attr_falsey_or_empty?(key2)
         end
         memoize(:"#{key1}?")
       end
@@ -141,6 +138,10 @@ module Twitter
 
   private
 
+    def attr_falsey_or_empty?(key)
+      @attrs[key].nil? || @attrs[key] == false || @attrs[key].respond_to?(:empty?) && @attrs[key].empty?
+    end
+
     def attrs_for_object(key1, key2 = nil)
       if key2.nil?
         @attrs[key1]
