@@ -1,23 +1,24 @@
 require 'twitter/enumerable'
+require 'twitter/rest/request'
 require 'twitter/utils'
 
 module Twitter
   class Cursor
     include Twitter::Enumerable
     include Twitter::Utils
+    # @return [Hash]
     attr_reader :attrs
-    alias_method :to_h, :attrs
-    deprecate_alias :to_hash, :to_h
-    deprecate_alias :to_hsh, :to_h
+    alias to_h attrs
+    alias to_hash to_h
+    deprecate_alias :to_hsh, :to_hash
 
     # Initializes a new Cursor
     #
-    # @param attrs [Hash]
     # @param key [String, Symbol] The key to fetch the data from the response
     # @param klass [Class] The class to instantiate objects in the response
-    # @param request [Twitter::Request]
+    # @param request [Twitter::REST::Request]
     # @return [Twitter::Cursor]
-    def initialize(attrs, key, klass, request)
+    def initialize(key, klass, request)
       @key = key.to_sym
       @klass = klass
       @client = request.client
@@ -25,7 +26,7 @@ module Twitter
       @path = request.path
       @options = request.options
       @collection = []
-      self.attrs = attrs
+      self.attrs = request.perform
     end
 
   private
@@ -34,7 +35,7 @@ module Twitter
     def next_cursor
       @attrs[:next_cursor] || -1
     end
-    alias_method :next, :next_cursor
+    alias next next_cursor
 
     # @return [Boolean]
     def last?
@@ -43,7 +44,7 @@ module Twitter
 
     # @return [Hash]
     def fetch_next_page
-      response = @client.send(@request_method, @path, @options.merge(:cursor => next_cursor)).body
+      response = Twitter::REST::Request.new(@client, @request_method, @path, @options.merge(:cursor => next_cursor)).perform
       self.attrs = response
     end
 
