@@ -1,12 +1,15 @@
+require 'memoizable'
 require 'twitter/base'
 
 module Twitter
   class ProfileBanner < Twitter::Base
+    include Memoizable
+
     # Returns an array of photo sizes
     #
     # @return [Array<Twitter::Size>]
     def sizes
-      Array(@attrs[:sizes]).inject({}) do |object, (key, value)|
+      @attrs.fetch(:sizes, []).inject({}) do |object, (key, value)|
         object[key] = Size.new(value)
         object
       end
