@@ -11,7 +11,7 @@ module Twitter
       include Twitter::REST::Utils
       include Twitter::Utils
 
-      # @see https://dev.twitter.com/docs/api/1.1/get/favorites/list
+      # @see https://dev.twitter.com/rest/reference/get/favorites/list
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -37,7 +37,7 @@ module Twitter
 
       # Un-favorites the specified Tweets as the authenticating user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/favorites/destroy
+      # @see https://dev.twitter.com/rest/reference/post/favorites/destroy
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -50,12 +50,12 @@ module Twitter
       def unfavorite(*args)
         parallel_objects_from_response(Twitter::Tweet, :post, '/1.1/favorites/destroy.json', args)
       end
-      alias_method :destroy_favorite, :unfavorite
+      alias destroy_favorite unfavorite
       deprecate_alias :favorite_destroy, :unfavorite
 
       # Favorites the specified Tweets as the authenticating user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/favorites/create
+      # @see https://dev.twitter.com/rest/reference/post/favorites/create
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -75,13 +75,13 @@ module Twitter
           end
         end.compact
       end
-      alias_method :fav, :favorite
-      alias_method :fave, :favorite
+      alias fav favorite
+      alias fave favorite
       deprecate_alias :favorite_create, :favorite
 
       # Favorites the specified Tweets as the authenticating user and raises an error if one has already been favorited
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/favorites/create
+      # @see https://dev.twitter.com/rest/reference/post/favorites/create
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::AlreadyFavorited] Error raised when tweet has already been favorited.
@@ -99,9 +99,9 @@ module Twitter
           perform_post_with_object('/1.1/favorites/create.json', arguments.options.merge(:id => extract_id(tweet)), Twitter::Tweet)
         end
       end
-      alias_method :create_favorite!, :favorite!
-      alias_method :fav!, :favorite!
-      alias_method :fave!, :favorite!
+      alias create_favorite! favorite!
+      alias fav! favorite!
+      alias fave! favorite!
       deprecate_alias :favorite_create!, :favorite!
     end
   end
