@@ -14,11 +14,11 @@ module Twitter
       include Twitter::REST::Utils
       include Twitter::Utils
       MAX_USERS_PER_REQUEST = 100
-      URI_SUBSTRING = '://'
+      URI_SUBSTRING = '://'.freeze
 
       # Returns all lists the authenticating or specified user subscribes to, including their own
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/list
+      # @see https://dev.twitter.com/rest/reference/get/lists/list
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -33,11 +33,11 @@ module Twitter
       def lists(*args)
         objects_from_response_with_user(Twitter::List, :get, '/1.1/lists/list.json', args)
       end
-      alias_method :lists_subscribed_to, :lists
+      alias lists_subscribed_to lists
 
       # Show tweet timeline for members of the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/statuses
+      # @see https://dev.twitter.com/rest/reference/get/lists/statuses
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -65,7 +65,7 @@ module Twitter
 
       # Removes the specified member from the list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/lists/members/destroy
+      # @see https://dev.twitter.com/rest/reference/post/lists/members/destroy
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -87,7 +87,7 @@ module Twitter
 
       # List the lists the specified user has been added to
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/memberships
+      # @see https://dev.twitter.com/rest/reference/get/lists/memberships
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -107,7 +107,7 @@ module Twitter
 
       # Returns the subscribers of the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/subscribers
+      # @see https://dev.twitter.com/rest/reference/get/lists/subscribers
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -126,7 +126,7 @@ module Twitter
 
       # Make the authenticated user follow the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/lists/subscribers/create
+      # @see https://dev.twitter.com/rest/reference/post/lists/subscribers/create
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -145,7 +145,7 @@ module Twitter
 
       # Check if a user is a subscriber of the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/subscribers/show
+      # @see https://dev.twitter.com/rest/reference/get/lists/subscribers/show
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -167,7 +167,7 @@ module Twitter
 
       # Unsubscribes the authenticated user form the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/lists/subscribers/destroy
+      # @see https://dev.twitter.com/rest/reference/post/lists/subscribers/destroy
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -186,7 +186,7 @@ module Twitter
 
       # Adds specified members to a list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/lists/members/create_all
+      # @see https://dev.twitter.com/rest/reference/post/lists/members/create_all
       # @note Lists are limited to having 5,000 members, and you are limited to adding up to 100 members to a list at a time with this method.
       # @rate_limited No
       # @authentication Requires user context
@@ -210,7 +210,7 @@ module Twitter
 
       # Check if a user is a member of the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/members/show
+      # @see https://dev.twitter.com/rest/reference/get/lists/members/show
       # @authentication Requires user context
       # @rate_limited Yes
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -231,7 +231,7 @@ module Twitter
 
       # Returns the members of the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/members
+      # @see https://dev.twitter.com/rest/reference/get/lists/members
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -250,7 +250,7 @@ module Twitter
 
       # Add a member to a list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/lists/members/create
+      # @see https://dev.twitter.com/rest/reference/post/lists/members/create
       # @note Lists are limited to having 5,000 members.
       # @rate_limited No
       # @authentication Requires user context
@@ -273,7 +273,7 @@ module Twitter
 
       # Deletes the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/lists/destroy
+      # @see https://dev.twitter.com/rest/reference/post/lists/destroy
       # @note Must be owned by the authenticated user.
       # @rate_limited No
       # @authentication Requires user context
@@ -294,7 +294,7 @@ module Twitter
 
       # Updates the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/lists/update
+      # @see https://dev.twitter.com/rest/reference/post/lists/update
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -317,7 +317,7 @@ module Twitter
 
       # Creates a new list for the authenticated user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/lists/create
+      # @see https://dev.twitter.com/rest/reference/post/lists/create
       # @note Accounts are limited to 20 lists.
       # @rate_limited No
       # @authentication Requires user context
@@ -334,7 +334,7 @@ module Twitter
 
       # Show the specified list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/show
+      # @see https://dev.twitter.com/rest/reference/get/lists/show
       # @note Private lists will only be shown if the authenticated user owns the specified list.
       # @rate_limited Yes
       # @authentication Requires user context
@@ -354,7 +354,7 @@ module Twitter
 
       # List the lists the specified user follows
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/subscriptions
+      # @see https://dev.twitter.com/rest/reference/get/lists/subscriptions
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -370,7 +370,7 @@ module Twitter
 
       # Removes specified members from the list
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/lists/members/destroy_all
+      # @see https://dev.twitter.com/rest/reference/post/lists/members/destroy_all
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::NotFound] Error raised when supplied list is not found.
@@ -392,7 +392,7 @@ module Twitter
 
       # Returns the lists owned by the specified Twitter user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/lists/ownerships
+      # @see https://dev.twitter.com/rest/reference/get/lists/ownerships
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
