@@ -7,7 +7,7 @@ module Twitter
     module Media
       # Uploads media to attach to a tweet
       #
-      # @see https://dev.twitter.com/docs/api/multiple-media-extended-entities
+      # @see https://dev.twitter.com/rest/public/uploading-media-multiple-photos
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -22,7 +22,7 @@ module Twitter
         conn = connection.dup
         conn.url_prefix = base_url
         headers = Twitter::Headers.new(self, :post, base_url + path, options).request_headers
-        options.merge!(:media => media)
+        options[:media] = media
         conn.post(path, options) { |request| request.headers.update(headers) }.env.body[:media_id]
       end
     end
