@@ -9,12 +9,11 @@ module Twitter
           status_code = response.status.to_i
           klass = Twitter::Error.errors[status_code]
           return unless klass
-          error = if klass == Twitter::Error::Forbidden
-            handle_forbidden_errors(response)
+          if klass == Twitter::Error::Forbidden
+            fail(handle_forbidden_errors(response))
           else
-            klass.from_response(response)
+            fail(klass.from_response(response))
           end
-          fail(error)
         end
 
       private
@@ -33,4 +32,4 @@ module Twitter
   end
 end
 
-Faraday::Response.register_middleware :raise_error => Twitter::REST::Response::RaiseError
+Faraday::Response.register_middleware :twitter_raise_error => Twitter::REST::Response::RaiseError
