@@ -15,7 +15,7 @@ module Twitter
 
       # Returns up to 100 of the first retweets of a given tweet
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/statuses/retweets/:id
+      # @see https://dev.twitter.com/rest/reference/get/statuses/retweets/:id
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -30,7 +30,7 @@ module Twitter
 
       # Show up to 100 users who retweeted the Tweet
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/statuses/retweets/:id
+      # @see https://dev.twitter.com/rest/reference/get/statuses/retweets/:id
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -48,7 +48,7 @@ module Twitter
 
       # Returns a Tweet
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/statuses/show/:id
+      # @see https://dev.twitter.com/rest/reference/get/statuses/show/:id
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -63,7 +63,7 @@ module Twitter
 
       # Returns Tweets
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/statuses/lookup
+      # @see https://dev.twitter.com/rest/reference/get/statuses/lookup
       # @rate_limited Yes
       # @authentication Required
       # @return [Array<Twitter::Tweet>] The requested Tweets.
@@ -82,7 +82,7 @@ module Twitter
 
       # Destroys the specified Tweets
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/statuses/destroy/:id
+      # @see https://dev.twitter.com/rest/reference/post/statuses/destroy/:id
       # @note The authenticating user must be the author of the specified Tweets.
       # @rate_limited No
       # @authentication Requires user context
@@ -100,22 +100,22 @@ module Twitter
           perform_post_with_object("/1.1/statuses/destroy/#{extract_id(tweet)}.json", arguments.options, Twitter::Tweet)
         end
       end
-      alias_method :destroy_tweet, :destroy_status
+      alias destroy_tweet destroy_status
       deprecate_alias :status_destroy, :destroy_status
       deprecate_alias :tweet_destroy, :destroy_status
 
       # Updates the authenticating user's status
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/statuses/update
+      # @see https://dev.twitter.com/rest/reference/post/statuses/update
       # @note A status update with text identical to the authenticating user's current status will be ignored to prevent duplicates.
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
-      # @return [Twitter::Tweet] The created Tweet.
+      # @return [Twitter::Tweet] The created Tweet. When the tweet is deemed a duplicate by Twitter, returns the last Tweet from the user's timeline.
       # @param status [String] The text of your status update, up to 140 characters.
       # @param options [Hash] A customizable set of options.
       # @option options [Boolean, String, Integer] :possibly_sensitive Set to true for content which may not be suitable for every audience.
-      # @option options [Twitter::Tweet] :in_reply_to_status An existing status that the update is in reply to.
+      # @option options [Twitter::Tweet] :in_reply_to_status An existing status that the update is in reply to. If the status being replied to was not originally posted by the authenticated user, the text of the status must begin with an @-mention, or twitter will reject the update.
       # @option options [Integer] :in_reply_to_status_id The ID of an existing status that the update is in reply to.
       # @option options [Float] :lat The latitude of the location this tweet refers to. This option will be ignored unless it is inside the range -90.0 to +90.0 (North is positive) inclusive. It will also be ignored if there isn't a corresponding :long option.
       # @option options [Float] :long The longitude of the location this tweet refers to. The valid ranges for longitude is -180.0 to +180.0 (East is positive) inclusive. This option will be ignored if outside that range, if it is not a number, if geo_enabled is disabled, or if there not a corresponding :lat option.
@@ -132,7 +132,7 @@ module Twitter
 
       # Updates the authenticating user's status
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/statuses/update
+      # @see https://dev.twitter.com/rest/reference/post/statuses/update
       # @note A status update with text identical to the authenticating user's current status will be ignored to prevent duplicates.
       # @rate_limited No
       # @authentication Requires user context
@@ -142,7 +142,7 @@ module Twitter
       # @param status [String] The text of your status update, up to 140 characters.
       # @param options [Hash] A customizable set of options.
       # @option options [Boolean, String, Integer] :possibly_sensitive Set to true for content which may not be suitable for every audience.
-      # @option options [Twitter::Tweet] :in_reply_to_status An existing status that the update is in reply to.
+      # @option options [Twitter::Tweet] :in_reply_to_status An existing status that the update is in reply to. If the status being replied to was not originally posted by the authenticated user, the text of the status must begin with an @-mention, or twitter will reject the update.
       # @option options [Integer] :in_reply_to_status_id The ID of an existing status that the update is in reply to.
       # @option options [Float] :lat The latitude of the location this tweet refers to. This option will be ignored unless it is inside the range -90.0 to +90.0 (North is positive) inclusive. It will also be ignored if there isn't a corresponding :long option.
       # @option options [Float] :long The longitude of the location this tweet refers to. The valid ranges for longitude is -180.0 to +180.0 (East is positive) inclusive. This option will be ignored if outside that range, if it is not a number, if geo_enabled is disabled, or if there not a corresponding :lat option.
@@ -160,7 +160,7 @@ module Twitter
 
       # Retweets the specified Tweets as the authenticating user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/statuses/retweet/:id
+      # @see https://dev.twitter.com/rest/reference/post/statuses/retweet/:id
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -184,7 +184,7 @@ module Twitter
 
       # Retweets the specified Tweets as the authenticating user and raises an error if one has already been retweeted
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/statuses/retweet/:id
+      # @see https://dev.twitter.com/rest/reference/post/statuses/retweet/:id
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::AlreadyRetweeted] Error raised when tweet has already been retweeted.
@@ -206,7 +206,7 @@ module Twitter
 
       # Updates the authenticating user's status with media
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/statuses/update_with_media
+      # @see https://dev.twitter.com/rest/reference/post/statuses/update_with_media
       # @note A status update with text/media identical to the authenticating user's current status will NOT be ignored
       # @rate_limited No
       # @authentication Requires user context
@@ -235,7 +235,7 @@ module Twitter
 
       # Returns oEmbed for a Tweet
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/statuses/oembed
+      # @see https://dev.twitter.com/rest/reference/get/statuses/oembed
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -243,12 +243,14 @@ module Twitter
       # @param tweet [Integer, String, URI, Twitter::Tweet] A Tweet ID, URI, or object.
       # @param options [Hash] A customizable set of options.
       # @option options [Integer] :maxwidth The maximum width in pixels that the embed should be rendered at. This value is constrained to be between 250 and 550 pixels.
-      # @option options [Boolean, String, Integer] :hide_media Specifies whether the embedded Tweet should automatically expand images which were uploaded via {https://dev.twitter.com/docs/api/1.1/post/statuses/update_with_media POST statuses/update_with_media}. When set to either true, t or 1 images will not be expanded. Defaults to false.
+      # @option options [Boolean, String, Integer] :hide_media Specifies whether the embedded Tweet should automatically expand images which were uploaded via {https://dev.twitter.com/rest/reference/post/statuses/update_with_media POST statuses/update_with_media}. When set to either true, t or 1 images will not be expanded. Defaults to false.
       # @option options [Boolean, String, Integer] :hide_thread Specifies whether the embedded Tweet should automatically show the original message in the case that the embedded Tweet is a reply. When set to either true, t or 1 the original Tweet will not be shown. Defaults to false.
       # @option options [Boolean, String, Integer] :omit_script Specifies whether the embedded Tweet HTML should include a `<script>` element pointing to widgets.js. In cases where a page already includes widgets.js, setting this value to true will prevent a redundant script element from being included. When set to either true, t or 1 the `<script>` element will not be included in the embed HTML, meaning that pages must include a reference to widgets.js manually. Defaults to false.
       # @option options [String] :align Specifies whether the embedded Tweet should be left aligned, right aligned, or centered in the page. Valid values are left, right, center, and none. Defaults to none, meaning no alignment styles are specified for the Tweet.
-      # @option options [String] :related A value for the TWT related parameter, as described in {https://dev.twitter.com/docs/intents Web Intents}. This value will be forwarded to all Web Intents calls.
+      # @option options [String] :related A value for the TWT related parameter, as described in {https://dev.twitter.com/web/intents Web Intents}. This value will be forwarded to all Web Intents calls.
       # @option options [String] :lang Language code for the rendered embed. This will affect the text and localization of the rendered HTML.
+      # @option options [String] :widget_type Set to video to return a Twitter Video embed for the given Tweet.
+      # @option options [Boolean, String] :hide_tweet Applies to video type only. Set to 1 or true to link directly to the Tweet URL instead of displaying a Tweet overlay when a viewer clicks on the Twitter bird logo.
       def oembed(tweet, options = {})
         options[:id] = extract_id(tweet)
         perform_get_with_object('/1.1/statuses/oembed.json', options, Twitter::OEmbed)
@@ -256,7 +258,7 @@ module Twitter
 
       # Returns oEmbeds for Tweets
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/statuses/oembed
+      # @see https://dev.twitter.com/rest/reference/get/statuses/oembed
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -267,11 +269,11 @@ module Twitter
       #   @param tweets [Enumerable<Integer, String, URI, Twitter::Tweet>] A collection of Tweet IDs, URIs, or objects.
       #   @param options [Hash] A customizable set of options.
       #   @option options [Integer] :maxwidth The maximum width in pixels that the embed should be rendered at. This value is constrained to be between 250 and 550 pixels.
-      #   @option options [Boolean, String, Integer] :hide_media Specifies whether the embedded Tweet should automatically expand images which were uploaded via {https://dev.twitter.com/docs/api/1.1/post/statuses/update_with_media POST statuses/update_with_media}. When set to either true, t or 1 images will not be expanded. Defaults to false.
+      #   @option options [Boolean, String, Integer] :hide_media Specifies whether the embedded Tweet should automatically expand images which were uploaded via {https://dev.twitter.com/rest/reference/post/statuses/update_with_media POST statuses/update_with_media}. When set to either true, t or 1 images will not be expanded. Defaults to false.
       #   @option options [Boolean, String, Integer] :hide_thread Specifies whether the embedded Tweet should automatically show the original message in the case that the embedded Tweet is a reply. When set to either true, t or 1 the original Tweet will not be shown. Defaults to false.
       #   @option options [Boolean, String, Integer] :omit_script Specifies whether the embedded Tweet HTML should include a `<script>` element pointing to widgets.js. In cases where a page already includes widgets.js, setting this value to true will prevent a redundant script element from being included. When set to either true, t or 1 the `<script>` element will not be included in the embed HTML, meaning that pages must include a reference to widgets.js manually. Defaults to false.
       #   @option options [String] :align Specifies whether the embedded Tweet should be left aligned, right aligned, or centered in the page. Valid values are left, right, center, and none. Defaults to none, meaning no alignment styles are specified for the Tweet.
-      #   @option options [String] :related A value for the TWT related parameter, as described in {https://dev.twitter.com/docs/intents Web Intents}. This value will be forwarded to all Web Intents calls.
+      #   @option options [String] :related A value for the TWT related parameter, as described in {https://dev.twitter.com/web/intents Web Intents}. This value will be forwarded to all Web Intents calls.
       #   @option options [String] :lang Language code for the rendered embed. This will affect the text and localization of the rendered HTML.
       def oembeds(*args)
         arguments = Twitter::Arguments.new(args)
@@ -282,7 +284,7 @@ module Twitter
 
       # Returns a collection of up to 100 user IDs belonging to users who have retweeted the tweet specified by the id parameter.
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/statuses/retweeters/ids
+      # @see https://dev.twitter.com/rest/reference/get/statuses/retweeters/ids
       # @rate_limited Yes
       # @authentication Required
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
