@@ -17,19 +17,19 @@ module Twitter
       # Updates the authenticating user's settings.
       # Or, if no options supplied, returns settings (including current trend, geo and sleep time information) for the authenticating user.
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/account/settings
-      # @see https://dev.twitter.com/docs/api/1.1/get/account/settings
+      # @see https://dev.twitter.com/rest/reference/post/account/settings
+      # @see https://dev.twitter.com/rest/reference/get/account/settings
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::Settings]
       # @param options [Hash] A customizable set of options.
-      # @option options [Integer] :trend_location_woeid The Yahoo! Where On Earth ID to use as the user's default trend location. Global information is available by using 1 as the WOEID. The woeid must be one of the locations returned by {https://dev.twitter.com/docs/api/1.1/get/trends/available GET trends/available}.
+      # @option options [Integer] :trend_location_woeid The Yahoo! Where On Earth ID to use as the user's default trend location. Global information is available by using 1 as the WOEID. The woeid must be one of the locations returned by {https://dev.twitter.com/rest/reference/get/trends/available GET trends/available}.
       # @option options [Boolean, String, Integer] :sleep_time_enabled When set to true, 't' or 1, will enable sleep time for the user. Sleep time is the time when push or SMS notifications should not be sent to the user.
       # @option options [Integer] :start_sleep_time The hour that sleep time should begin if it is enabled. The value for this parameter should be provided in {http://en.wikipedia.org/wiki/ISO_8601 ISO8601} format (i.e. 00-23). The time is considered to be in the same timezone as the user's time_zone setting.
       # @option options [Integer] :end_sleep_time The hour that sleep time should end if it is enabled. The value for this parameter should be provided in {http://en.wikipedia.org/wiki/ISO_8601 ISO8601} format (i.e. 00-23). The time is considered to be in the same timezone as the user's time_zone setting.
       # @option options [String] :time_zone The timezone dates and times should be displayed in for the user. The timezone must be one of the {http://api.rubyonrails.org/classes/ActiveSupport/TimeZone.html Rails TimeZone} names.
-      # @option options [String] :lang The language which Twitter should render in for this user. The language must be specified by the appropriate two letter ISO 639-1 representation. Currently supported languages are provided by {https://dev.twitter.com/docs/api/1.1/get/help/languages GET help/languages}.
+      # @option options [String] :lang The language which Twitter should render in for this user. The language must be specified by the appropriate two letter ISO 639-1 representation. Currently supported languages are provided by {https://dev.twitter.com/rest/reference/get/help/languages GET help/languages}.
       def settings(options = {})
         request_method = options.size.zero? ? :get : :post
         response = perform_request(request_method.to_sym, '/1.1/account/settings.json', options)
@@ -40,7 +40,7 @@ module Twitter
 
       # Returns the requesting user if authentication was successful, otherwise raises {Twitter::Error::Unauthorized}
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/account/verify_credentials
+      # @see https://dev.twitter.com/rest/reference/get/account/verify_credentials
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -50,11 +50,11 @@ module Twitter
       def verify_credentials(options = {})
         perform_get_with_object('/1.1/account/verify_credentials.json', options, Twitter::User)
       end
-      alias_method :current_user, :verify_credentials
+      alias current_user verify_credentials
 
       # Sets which device Twitter delivers updates to for the authenticating user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/account/update_delivery_device
+      # @see https://dev.twitter.com/rest/reference/post/account/update_delivery_device
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -67,7 +67,7 @@ module Twitter
 
       # Sets values that users are able to set under the "Account" tab of their settings page
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/account/update_profile
+      # @see https://dev.twitter.com/rest/reference/post/account/update_profile
       # @note Only the options specified will be updated.
       # @rate_limited No
       # @authentication Requires user context
@@ -84,7 +84,7 @@ module Twitter
 
       # Updates the authenticating user's profile background image
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/account/update_profile_background_image
+      # @see https://dev.twitter.com/rest/reference/post/account/update_profile_background_image
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -98,7 +98,7 @@ module Twitter
 
       # Sets one or more hex values that control the color scheme of the authenticating user's profile
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/account/update_profile_colors
+      # @see https://dev.twitter.com/rest/reference/post/account/update_profile_colors
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -115,7 +115,7 @@ module Twitter
 
       # Updates the authenticating user's profile image
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/account/update_profile_image
+      # @see https://dev.twitter.com/rest/reference/post/account/update_profile_image
       # @note Updates the authenticating user's profile image. Note that this method expects raw multipart data, not a URL to an image.
       # @note This method asynchronously processes the uploaded file before updating the user's profile image URL. You can either update your local cache the next time you request the user's information, or, at least 5 seconds after uploading the image, ask for the updated URL using GET users/show.
       # @rate_limited No
@@ -130,7 +130,7 @@ module Twitter
 
       # Returns an array of user objects that the authenticating user is blocking
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/blocks/list
+      # @see https://dev.twitter.com/rest/reference/get/blocks/list
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -144,7 +144,7 @@ module Twitter
 
       # Returns an array of numeric user IDs the authenticating user is blocking
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/blocks/ids
+      # @see https://dev.twitter.com/rest/reference/get/blocks/ids
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -159,7 +159,7 @@ module Twitter
 
       # Returns true if the authenticating user is blocking a target user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/blocks/ids
+      # @see https://dev.twitter.com/rest/reference/get/blocks/ids
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -183,7 +183,7 @@ module Twitter
 
       # Blocks the users specified by the authenticating user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/blocks/create
+      # @see https://dev.twitter.com/rest/reference/post/blocks/create
       # @note Destroys a friendship to the blocked user if it exists.
       # @rate_limited Yes
       # @authentication Requires user context
@@ -200,7 +200,7 @@ module Twitter
 
       # Un-blocks the users specified by the authenticating user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/blocks/destroy
+      # @see https://dev.twitter.com/rest/reference/post/blocks/destroy
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -216,7 +216,7 @@ module Twitter
 
       # Returns extended information for up to 100 users
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/users/lookup
+      # @see https://dev.twitter.com/rest/reference/get/users/lookup
       # @rate_limited Yes
       # @authentication Required
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -233,7 +233,7 @@ module Twitter
         end
       end
 
-      # @see https://dev.twitter.com/docs/api/1.1/get/users/show
+      # @see https://dev.twitter.com/rest/reference/get/users/show
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -276,7 +276,7 @@ module Twitter
 
       # Returns users that match the given query
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/users/search
+      # @see https://dev.twitter.com/rest/reference/get/users/search
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -291,7 +291,7 @@ module Twitter
 
       # Returns an array of users that the specified user can contribute to
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/users/contributees
+      # @see https://dev.twitter.com/rest/reference/get/users/contributees
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -309,7 +309,7 @@ module Twitter
 
       # Returns an array of users who can contribute to the specified account
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/users/contributors
+      # @see https://dev.twitter.com/rest/reference/get/users/contributors
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -327,7 +327,7 @@ module Twitter
 
       # Removes the authenticating user's profile banner image
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/account/remove_profile_banner
+      # @see https://dev.twitter.com/rest/reference/post/account/remove_profile_banner
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -341,7 +341,7 @@ module Twitter
 
       # Updates the authenticating user's profile banner image
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/account/update_profile_banner
+      # @see https://dev.twitter.com/rest/reference/post/account/update_profile_banner
       # @note Uploads a profile banner on behalf of the authenticating user. For best results, upload an <5MB image that is exactly 1252px by 626px. Images will be resized for a number of display options. Users with an uploaded profile banner will have a profile_banner_url node in their Users objects. More information about sizing variations can be found in User Profile Images and Banners.
       # @note Profile banner images are processed asynchronously. The profile_banner_url and its variant sizes will not necessary be available directly after upload.
       # @rate_limited No
@@ -363,7 +363,7 @@ module Twitter
 
       # Returns the available size variations of the specified user's profile banner.
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/users/profile_banner
+      # @see https://dev.twitter.com/rest/reference/get/users/profile_banner
       # @note If the user has not uploaded a profile banner, a HTTP 404 will be served instead.
       # @rate_limited Yes
       # @authentication Requires user context
@@ -380,7 +380,7 @@ module Twitter
 
       # Mutes the users specified by the authenticating user
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/mutes/users/create
+      # @see https://dev.twitter.com/rest/reference/post/mutes/users/create
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -396,7 +396,7 @@ module Twitter
 
       # Un-mutes the user specified by the authenticating user.
       #
-      # @see https://dev.twitter.com/docs/api/1.1/post/mutes/users/destroy
+      # @see https://dev.twitter.com/rest/reference/post/mutes/users/destroy
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -412,7 +412,7 @@ module Twitter
 
       # Returns an array of user objects that the authenticating user is muting
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/mutes/users/list
+      # @see https://dev.twitter.com/rest/reference/get/mutes/users/list
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
@@ -426,7 +426,7 @@ module Twitter
 
       # Returns an array of numeric user IDs the authenticating user is muting
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/mutes/users/ids
+      # @see https://dev.twitter.com/rest/reference/get/mutes/users/ids
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
