@@ -9,7 +9,7 @@ module Twitter
   module REST
     module Utils
       include Twitter::Utils
-      URI_SUBSTRING = '://'
+      URI_SUBSTRING = '://'.freeze
       DEFAULT_CURSOR = -1
 
     private
@@ -39,7 +39,6 @@ module Twitter
 
       # @param path [String]
       # @param options [Hash]
-      # @param klass [Class]
       def perform_post(path, options = {})
         perform_request(:post, path, options)
       end
@@ -100,7 +99,7 @@ module Twitter
 
       # @param path [String]
       # @param options [Hash]
-      # @collection_name [Symbol]
+      # @param collection_name [Symbol]
       # @param klass [Class]
       def perform_get_with_cursor(path, options, collection_name, klass = nil)
         merge_default_cursor!(options)
@@ -157,7 +156,7 @@ module Twitter
       # @param path [String]
       # @param args [Array]
       # @return [Twitter::Cursor]
-      def cursor_from_response_with_user(collection_name, klass, path, args) # rubocop:disable ParameterLists
+      def cursor_from_response_with_user(collection_name, klass, path, args)
         arguments = Twitter::Arguments.new(args)
         merge_user!(arguments.options, arguments.pop || user_id) unless arguments.options[:user_id] || arguments.options[:screen_name]
         perform_get_with_cursor(path, arguments.options, collection_name, klass)
@@ -233,18 +232,15 @@ module Twitter
         hash
       end
 
-      def collect_user_ids_and_screen_names(users) # rubocop:disable MethodLength
-        user_ids, screen_names = [], []
+      def collect_user_ids_and_screen_names(users)
+        user_ids = []
+        screen_names = []
         users.flatten.each do |user|
           case user
           when Integer
             user_ids << user
           when String
-            if user[URI_SUBSTRING]
-              screen_names << user.split('/').last
-            else
-              screen_names << user
-            end
+            screen_names << (user[URI_SUBSTRING] ? user.split('/').last : user)
           when URI
             screen_names << user.path.split('/').last
           when Twitter::User
