@@ -1,12 +1,15 @@
+require 'memoizable'
 require 'twitter/base'
 
 module Twitter
   class Token < Twitter::Base
+    include Memoizable
+
     # @return [String]
     attr_reader :access_token, :token_type
-    alias_method :to_s, :access_token
+    alias to_s access_token
 
-    BEARER_TYPE = 'bearer'
+    BEARER_TYPE = 'bearer'.freeze
 
     # @return [Boolean]
     def bearer?
