@@ -4,7 +4,8 @@ require 'twitter/base'
 module Twitter
   class Trend < Twitter::Base
     include Equalizer.new(:name)
-    attr_reader :events, :name, :query
+    # @return [String]
+    attr_reader :events, :name, :query, :tweet_volume
     predicate_attr_reader :promoted_content
     uri_attr_reader :uri
   end
