@@ -10,10 +10,11 @@ module Twitter
     include Twitter::Enumerable
     include Twitter::Utils
     include Memoizable
+    # @return [Hash]
     attr_reader :attrs
-    alias_method :to_h, :attrs
-    deprecate_alias :to_hash, :to_h
-    deprecate_alias :to_hsh, :to_h
+    alias to_h attrs
+    alias to_hash to_h
+    deprecate_alias :to_hsh, :to_hash
 
     # Initializes a new TrendResults object
     #
