@@ -10,22 +10,22 @@ module Twitter
     include Twitter::Creatable
     include Twitter::Profile
     include Memoizable
-    attr_reader :connections, :description, :favourites_count,
-                :followers_count, :friends_count, :lang, :listed_count,
-                :location, :name, :profile_background_color,
-                :profile_background_image_url,
-                :profile_background_image_url_https, :profile_link_color,
+    # @return [Array]
+    attr_reader :connections
+    # @return [Integer]
+    attr_reader :favourites_count, :followers_count, :friends_count,
+                :listed_count, :statuses_count, :utc_offset
+    # @return [String]
+    attr_reader :description, :lang, :location, :name,
+                :profile_background_color, :profile_link_color,
                 :profile_sidebar_border_color, :profile_sidebar_fill_color,
-                :profile_text_color, :statuses_count, :time_zone, :utc_offset
-    alias_method :favorites_count, :favourites_count
-    remove_method :favourites_count
-    alias_method :profile_background_image_uri, :profile_background_image_url
-    alias_method :profile_background_image_uri_https, :profile_background_image_url_https
-    alias_method :tweets_count, :statuses_count
+                :profile_text_color, :time_zone
+    alias favorites_count favourites_count
+    alias tweets_count statuses_count
     object_attr_reader :Tweet, :status, :user
-    alias_method :tweet, :status
-    alias_method :tweet?, :status?
-    alias_method :tweeted?, :status?
+    alias tweet status
+    alias tweet? status?
+    alias tweeted? status?
     predicate_attr_reader :contributors_enabled, :default_profile,
                           :default_profile_image, :follow_request_sent,
                           :geo_enabled, :muting, :needs_phone_verification,
@@ -33,6 +33,7 @@ module Twitter
                           :profile_use_background_image, :suspended, :verified
     define_predicate_method :translator, :is_translator
     define_predicate_method :translation_enabled, :is_translation_enabled
+    uri_attr_reader :profile_background_image_uri, :profile_background_image_uri_https
 
     class << self
     private
@@ -78,17 +79,17 @@ module Twitter
     end
     memoize :entities?
 
-    # @return [String] The URL to the user.
+    # @return [Addressable::URI] The URL to the user.
     def uri
-      Addressable::URI.parse("https://twitter.com/#{screen_name}") unless screen_name.nil?
+      Addressable::URI.parse("https://twitter.com/#{screen_name}") if screen_name?
     end
     memoize :uri
-    alias_method :url, :uri
+    alias url uri
 
-    # @return [String] The URL to the user's website.
+    # @return [Addressable::URI] The URL to the user's website.
     def website
-      if website_urls?
-        website_urls.first.expanded_url
+      if website_uris?
+        website_uris.first.expanded_url
       else
         Addressable::URI.parse(@attrs[:url])
       end
